==> deepin-dock-debug-5.5.81-2-x86_64.pkg.tar.zst: usr/src/debug/deepin-dock/dde-dock-5.5.81/plugins/overlay-warning/overlay-warning_autogen/EWIEGA46WW/qrc_overlay-warning.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.9
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-dock/src/dde-dock-5.5.81/plugins/overlay-warning/resources/icons/overlay-warning.svg
  0x0,0x0,0x2,0xd2,
  0x3c,
  0x73,0x76,0x67,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,
  0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x32,0x30,0x30,
  0x30,0x2f,0x73,0x76,0x67,0x22,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x36,
  0x22,0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x31,0x36,0x22,0x20,0x76,0x69,
  0x65,0x77,0x42,0x6f,0x78,0x3d,0x22,0x30,0x20,0x30,0x20,0x31,0x36,0x20,0x31,0x36,
  0x22,0x3e,0xa,0x20,0x20,0x3c,0x70,0x61,0x74,0x68,0x20,0x66,0x69,0x6c,0x6c,0x3d,
  0x22,0x23,0x45,0x42,0x39,0x39,0x30,0x30,0x22,0x20,0x64,0x3d,0x22,0x4d,0x37,0x2e,
  0x36,0x33,0x33,0x38,0x31,0x34,0x34,0x31,0x2c,0x32,0x2e,0x35,0x30,0x31,0x33,0x38,
  0x38,0x33,0x35,0x20,0x4c,0x31,0x2e,0x38,0x36,0x35,0x32,0x32,0x34,0x34,0x39,0x2c,
  0x31,0x32,0x2e,0x35,0x30,0x30,0x32,0x37,0x37,0x35,0x20,0x43,0x31,0x2e,0x35,0x38,
  0x39,0x32,0x33,0x35,0x34,0x2c,0x31,0x32,0x2e,0x39,0x37,0x38,0x36,0x35,0x38,0x36,
  0x20,0x31,0x2e,0x37,0x35,0x33,0x33,0x30,0x36,0x35,0x34,0x2c,0x31,0x33,0x2e,0x35,
  0x39,0x30,0x31,0x39,0x36,0x35,0x20,0x32,0x2e,0x32,0x33,0x31,0x36,0x38,0x37,0x36,
  0x32,0x2c,0x31,0x33,0x2e,0x38,0x36,0x36,0x31,0x38,0x35,0x36,0x20,0x43,0x32,0x2e,
  0x33,0x38,0x33,0x36,0x34,0x30,0x38,0x33,0x2c,0x31,0x33,0x2e,0x39,0x35,0x33,0x38,
  0x35,0x30,0x39,0x20,0x32,0x2e,0x35,0x35,0x35,0x39,0x38,0x32,0x30,0x38,0x2c,0x31,
  0x34,0x20,0x32,0x2e,0x37,0x33,0x31,0x34,0x31,0x30,0x30,0x38,0x2c,0x31,0x34,0x20,
  0x4c,0x31,0x34,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x34,0x20,0x43,
  0x31,0x34,0x2e,0x38,0x32,0x30,0x38,0x37,0x34,0x37,0x2c,0x31,0x34,0x20,0x31,0x35,
  0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x33,0x2e,0x35,0x35,0x32,0x32,
  0x38,0x34,0x37,0x20,0x31,0x35,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,
  0x33,0x20,0x43,0x31,0x35,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x32,
  0x2e,0x38,0x32,0x34,0x35,0x37,0x32,0x20,0x31,0x35,0x2e,0x32,0x32,0x32,0x34,0x34,
  0x30,0x38,0x2c,0x31,0x32,0x2e,0x36,0x35,0x32,0x32,0x33,0x30,0x37,0x20,0x31,0x35,
  0x2e,0x31,0x33,0x34,0x37,0x37,0x35,0x35,0x2c,0x31,0x32,0x2e,0x35,0x30,0x30,0x32,
  0x37,0x37,0x35,0x20,0x4c,0x39,0x2e,0x33,0x36,0x36,0x31,0x38,0x35,0x35,0x39,0x2c,
  0x32,0x2e,0x35,0x30,0x31,0x33,0x38,0x38,0x33,0x35,0x20,0x43,0x39,0x2e,0x30,0x39,
  0x30,0x31,0x39,0x36,0x35,0x2c,0x32,0x2e,0x30,0x32,0x33,0x30,0x30,0x37,0x32,0x36,
  0x20,0x38,0x2e,0x34,0x37,0x38,0x36,0x35,0x38,0x36,0x34,0x2c,0x31,0x2e,0x38,0x35,
  0x38,0x39,0x33,0x36,0x31,0x33,0x20,0x38,0x2e,0x30,0x30,0x30,0x32,0x37,0x37,0x35,
  0x35,0x2c,0x32,0x2e,0x31,0x33,0x34,0x39,0x32,0x35,0x32,0x32,0x20,0x43,0x37,0x2e,
  0x38,0x34,0x38,0x30,0x34,0x31,0x39,0x36,0x2c,0x32,0x2e,0x32,0x32,0x32,0x37,0x35,
  0x33,0x34,0x34,0x20,0x37,0x2e,0x37,0x32,0x31,0x36,0x34,0x32,0x36,0x34,0x2c,0x32,
  0x2e,0x33,0x34,0x39,0x31,0x35,0x32,0x37,0x36,0x20,0x37,0x2e,0x36,0x33,0x33,0x38,
  0x31,0x34,0x34,0x31,0x2c,0x32,0x2e,0x35,0x30,0x31,0x33,0x38,0x38,0x33,0x35,0x20,
  0x5a,0x20,0x4d,0x38,0x2c,0x35,0x20,0x4c,0x39,0x2c,0x35,0x20,0x4c,0x39,0x2c,0x39,
  0x20,0x4c,0x38,0x2c,0x39,0x20,0x4c,0x38,0x2c,0x35,0x20,0x5a,0x20,0x4d,0x38,0x2e,
  0x35,0x2c,0x31,0x32,0x20,0x43,0x37,0x2e,0x39,0x34,0x38,0x2c,0x31,0x32,0x20,0x37,
  0x2e,0x35,0x2c,0x31,0x31,0x2e,0x35,0x35,0x32,0x20,0x37,0x2e,0x35,0x2c,0x31,0x31,
  0x20,0x43,0x37,0x2e,0x35,0x2c,0x31,0x30,0x2e,0x34,0x34,0x38,0x20,0x37,0x2e,0x39,
  0x34,0x38,0x2c,0x31,0x30,0x20,0x38,0x2e,0x35,0x2c,0x31,0x30,0x20,0x43,0x39,0x2e,
  0x30,0x35,0x32,0x2c,0x31,0x30,0x20,0x39,0x2e,0x35,0x2c,0x31,0x30,0x2e,0x34,0x34,
  0x38,0x20,0x39,0x2e,0x35,0x2c,0x31,0x31,0x20,0x43,0x39,0x2e,0x35,0x2c,0x31,0x31,
  0x2e,0x35,0x35,0x32,0x20,0x39,0x2e,0x30,0x35,0x32,0x2c,0x31,0x32,0x20,0x38,0x2e,
  0x35,0x2c,0x31,0x32,0x20,0x5a,0x22,0x2f,0x3e,0xa,0x3c,0x2f,0x73,0x76,0x67,0x3e,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // resources
  0x0,0x9,
  0xa,0x6c,0x78,0x43,
  0x0,0x72,
  0x0,0x65,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,0x73,
    // overlay-warning.svg
  0x0,0x13,
  0xf,0xe3,0x1,0xe7,
  0x0,0x6f,
  0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,0x79,0x0,0x2d,0x0,0x77,0x0,0x61,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x73,
  0x0,0x76,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x87,0x65,0x2,0x5,0x60,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x87,0x65,0x2,0x5,0x60,
  // :/icons/resources
  0x0,0x0,0x0,0x10,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x87,0x65,0x2,0x5,0x60,
  // :/icons/resources/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x87,0x65,0x2,0x5,0x60,
  // :/icons/resources/icons/overlay-warning.svg
  0x0,0x0,0x0,0x28,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x87,0x65,0x2,0x5,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)(); }
   } dummy;
}

==> deepin-dock-debug-6.0.30-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-dock/dde-dock-6.0.30/plugins/overlay-warning/overlay-warning_autogen/EWIEGA46WW/qrc_overlay-warning.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.12
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-dock/src/dde-dock-6.0.30/plugins/overlay-warning/resources/icons/overlay-warning.svg
  0x0,0x0,0x2,0xd2,
  0x3c,
  0x73,0x76,0x67,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,
  0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x32,0x30,0x30,
  0x30,0x2f,0x73,0x76,0x67,0x22,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x36,
  0x22,0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x31,0x36,0x22,0x20,0x76,0x69,
  0x65,0x77,0x42,0x6f,0x78,0x3d,0x22,0x30,0x20,0x30,0x20,0x31,0x36,0x20,0x31,0x36,
  0x22,0x3e,0xa,0x20,0x20,0x3c,0x70,0x61,0x74,0x68,0x20,0x66,0x69,0x6c,0x6c,0x3d,
  0x22,0x23,0x45,0x42,0x39,0x39,0x30,0x30,0x22,0x20,0x64,0x3d,0x22,0x4d,0x37,0x2e,
  0x36,0x33,0x33,0x38,0x31,0x34,0x34,0x31,0x2c,0x32,0x2e,0x35,0x30,0x31,0x33,0x38,
  0x38,0x33,0x35,0x20,0x4c,0x31,0x2e,0x38,0x36,0x35,0x32,0x32,0x34,0x34,0x39,0x2c,
  0x31,0x32,0x2e,0x35,0x30,0x30,0x32,0x37,0x37,0x35,0x20,0x43,0x31,0x2e,0x35,0x38,
  0x39,0x32,0x33,0x35,0x34,0x2c,0x31,0x32,0x2e,0x39,0x37,0x38,0x36,0x35,0x38,0x36,
  0x20,0x31,0x2e,0x37,0x35,0x33,0x33,0x30,0x36,0x35,0x34,0x2c,0x31,0x33,0x2e,0x35,
  0x39,0x30,0x31,0x39,0x36,0x35,0x20,0x32,0x2e,0x32,0x33,0x31,0x36,0x38,0x37,0x36,
  0x32,0x2c,0x31,0x33,0x2e,0x38,0x36,0x36,0x31,0x38,0x35,0x36,0x20,0x43,0x32,0x2e,
  0x33,0x38,0x33,0x36,0x34,0x30,0x38,0x33,0x2c,0x31,0x33,0x2e,0x39,0x35,0x33,0x38,
  0x35,0x30,0x39,0x20,0x32,0x2e,0x35,0x35,0x35,0x39,0x38,0x32,0x30,0x38,0x2c,0x31,
  0x34,0x20,0x32,0x2e,0x37,0x33,0x31,0x34,0x31,0x30,0x30,0x38,0x2c,0x31,0x34,0x20,
  0x4c,0x31,0x34,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x34,0x20,0x43,
  0x31,0x34,0x2e,0x38,0x32,0x30,0x38,0x37,0x34,0x37,0x2c,0x31,0x34,0x20,0x31,0x35,
  0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x33,0x2e,0x35,0x35,0x32,0x32,
  0x38,0x34,0x37,0x20,0x31,0x35,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,
  0x33,0x20,0x43,0x31,0x35,0x2e,0x32,0x36,0x38,0x35,0x38,0x39,0x39,0x2c,0x31,0x32,
  0x2e,0x38,0x32,0x34,0x35,0x37,0x32,0x20,0x31,0x35,0x2e,0x32,0x32,0x32,0x34,0x34,
  0x30,0x38,0x2c,0x31,0x32,0x2e,0x36,0x35,0x32,0x32,0x33,0x30,0x37,0x20,0x31,0x35,
  0x2e,0x31,0x33,0x34,0x37,0x37,0x35,0x35,0x2c,0x31,0x32,0x2e,0x35,0x30,0x30,0x32,
  0x37,0x37,0x35,0x20,0x4c,0x39,0x2e,0x33,0x36,0x36,0x31,0x38,0x35,0x35,0x39,0x2c,
  0x32,0x2e,0x35,0x30,0x31,0x33,0x38,0x38,0x33,0x35,0x20,0x43,0x39,0x2e,0x30,0x39,
  0x30,0x31,0x39,0x36,0x35,0x2c,0x32,0x2e,0x30,0x32,0x33,0x30,0x30,0x37,0x32,0x36,
  0x20,0x38,0x2e,0x34,0x37,0x38,0x36,0x35,0x38,0x36,0x34,0x2c,0x31,0x2e,0x38,0x35,
  0x38,0x39,0x33,0x36,0x31,0x33,0x20,0x38,0x2e,0x30,0x30,0x30,0x32,0x37,0x37,0x35,
  0x35,0x2c,0x32,0x2e,0x31,0x33,0x34,0x39,0x32,0x35,0x32,0x32,0x20,0x43,0x37,0x2e,
  0x38,0x34,0x38,0x30,0x34,0x31,0x39,0x36,0x2c,0x32,0x2e,0x32,0x32,0x32,0x37,0x35,
  0x33,0x34,0x34,0x20,0x37,0x2e,0x37,0x32,0x31,0x36,0x34,0x32,0x36,0x34,0x2c,0x32,
  0x2e,0x33,0x34,0x39,0x31,0x35,0x32,0x37,0x36,0x20,0x37,0x2e,0x36,0x33,0x33,0x38,
  0x31,0x34,0x34,0x31,0x2c,0x32,0x2e,0x35,0x30,0x31,0x33,0x38,0x38,0x33,0x35,0x20,
  0x5a,0x20,0x4d,0x38,0x2c,0x35,0x20,0x4c,0x39,0x2c,0x35,0x20,0x4c,0x39,0x2c,0x39,
  0x20,0x4c,0x38,0x2c,0x39,0x20,0x4c,0x38,0x2c,0x35,0x20,0x5a,0x20,0x4d,0x38,0x2e,
  0x35,0x2c,0x31,0x32,0x20,0x43,0x37,0x2e,0x39,0x34,0x38,0x2c,0x31,0x32,0x20,0x37,
  0x2e,0x35,0x2c,0x31,0x31,0x2e,0x35,0x35,0x32,0x20,0x37,0x2e,0x35,0x2c,0x31,0x31,
  0x20,0x43,0x37,0x2e,0x35,0x2c,0x31,0x30,0x2e,0x34,0x34,0x38,0x20,0x37,0x2e,0x39,
  0x34,0x38,0x2c,0x31,0x30,0x20,0x38,0x2e,0x35,0x2c,0x31,0x30,0x20,0x43,0x39,0x2e,
  0x30,0x35,0x32,0x2c,0x31,0x30,0x20,0x39,0x2e,0x35,0x2c,0x31,0x30,0x2e,0x34,0x34,
  0x38,0x20,0x39,0x2e,0x35,0x2c,0x31,0x31,0x20,0x43,0x39,0x2e,0x35,0x2c,0x31,0x31,
  0x2e,0x35,0x35,0x32,0x20,0x39,0x2e,0x30,0x35,0x32,0x2c,0x31,0x32,0x20,0x38,0x2e,
  0x35,0x2c,0x31,0x32,0x20,0x5a,0x22,0x2f,0x3e,0xa,0x3c,0x2f,0x73,0x76,0x67,0x3e,
  0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // resources
  0x0,0x9,
  0xa,0x6c,0x78,0x43,
  0x0,0x72,
  0x0,0x65,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,0x73,
    // overlay-warning.svg
  0x0,0x13,
  0xf,0xe3,0x1,0xe7,
  0x0,0x6f,
  0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,0x79,0x0,0x2d,0x0,0x77,0x0,0x61,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x73,
  0x0,0x76,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8d,0x9f,0xc1,0x1a,0x28,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8d,0x9f,0xc1,0x1a,0x28,
  // :/icons/resources
  0x0,0x0,0x0,0x10,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x8d,0x9f,0xc1,0x1a,0x28,
  // :/icons/resources/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x8d,0x9f,0xc1,0x1a,0x28,
  // :/icons/resources/icons/overlay-warning.svg
  0x0,0x0,0x0,0x28,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8d,0x9f,0xc1,0x1a,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_overlay_warning)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_overlay_warning)(); }
   } dummy;
}
